# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Policy(pulumi.CustomResource):
    controls: pulumi.Output[list]
    """
    Specifies the controls
    """
    name: pulumi.Output[str]
    published_copy: pulumi.Output[str]
    """
    If you want to publish the policy else it will be deployed in Drafts mode.
    """
    requires: pulumi.Output[list]
    """
    Specifies the protocol
    """
    rules: pulumi.Output[list]
    """
    Rules can be applied using the policy
    
      * `actions` (`list`)
    
        * `app_service` (`str`)
        * `application` (`str`)
        * `asm` (`bool`)
        * `avr` (`bool`)
        * `cache` (`bool`)
        * `carp` (`bool`)
        * `category` (`str`)
        * `classify` (`bool`)
        * `clonePool` (`str`)
        * `code` (`float`)
        * `compress` (`bool`)
        * `content` (`str`)
        * `cookieHash` (`bool`)
        * `cookieInsert` (`bool`)
        * `cookiePassive` (`bool`)
        * `cookieRewrite` (`bool`)
        * `decompress` (`bool`)
        * `defer` (`bool`)
        * `destinationAddress` (`bool`)
        * `disable` (`bool`)
        * `domain` (`str`)
        * `enable` (`bool`)
        * `expiry` (`str`)
        * `expirySecs` (`float`)
        * `expression` (`str`)
        * `extension` (`str`)
        * `facility` (`str`)
        * `forward` (`bool`) - This action will affect forwarding.
        * `fromProfile` (`str`)
        * `hash` (`bool`)
        * `host` (`str`)
        * `http` (`bool`)
        * `httpBasicAuth` (`bool`)
        * `httpCookie` (`bool`)
        * `httpHeader` (`bool`)
        * `httpHost` (`bool`)
        * `httpReferer` (`bool`)
        * `httpReply` (`bool`)
        * `httpSetCookie` (`bool`)
        * `httpUri` (`bool`)
        * `ifile` (`str`)
        * `insert` (`bool`)
        * `internalVirtual` (`str`)
        * `ipAddress` (`str`)
        * `key` (`str`)
        * `l7dos` (`bool`)
        * `length` (`float`)
        * `location` (`str`)
        * `log` (`bool`)
        * `ltmPolicy` (`bool`)
        * `member` (`str`)
        * `message` (`str`)
        * `netmask` (`str`)
        * `nexthop` (`str`)
        * `node` (`str`)
        * `offset` (`float`)
        * `path` (`str`)
        * `pem` (`bool`)
        * `persist` (`bool`)
        * `pin` (`bool`)
        * `policy` (`str`)
        * `pool` (`str`) - This action will direct the stream to this pool.
        * `port` (`float`)
        * `priority` (`str`)
        * `profile` (`str`)
        * `protocol` (`str`)
        * `queryString` (`str`)
        * `rateclass` (`str`)
        * `redirect` (`bool`)
        * `remove` (`bool`)
        * `replace` (`bool`)
        * `request` (`bool`)
        * `requestAdapt` (`bool`)
        * `reset` (`bool`)
        * `response` (`bool`)
        * `responseAdapt` (`bool`)
        * `scheme` (`str`)
        * `script` (`str`)
        * `select` (`bool`)
        * `serverSsl` (`bool`)
        * `setVariable` (`bool`)
        * `snat` (`str`)
        * `snatpool` (`str`)
        * `sourceAddress` (`bool`)
        * `sslClientHello` (`bool`)
        * `sslServerHandshake` (`bool`)
        * `sslServerHello` (`bool`)
        * `sslSessionId` (`bool`)
        * `status` (`float`)
        * `tcl` (`bool`)
        * `tcpNagle` (`bool`)
        * `text` (`str`)
        * `timeout` (`float`)
        * `tmName` (`str`) - If Rule is used then you need to provide the tm_name it can be any value
        * `uie` (`bool`)
        * `universal` (`bool`)
        * `value` (`str`)
        * `virtual` (`str`)
        * `vlan` (`str`)
        * `vlanId` (`float`)
        * `wam` (`bool`)
        * `write` (`bool`)
    
      * `conditions` (`list`)
    
        * `address` (`bool`)
        * `all` (`bool`)
        * `app_service` (`str`)
        * `browserType` (`bool`)
        * `browserVersion` (`bool`)
        * `caseInsensitive` (`bool`)
        * `caseSensitive` (`bool`)
        * `cipher` (`bool`)
        * `cipherBits` (`bool`)
        * `clientSsl` (`bool`)
        * `code` (`bool`)
        * `commonName` (`bool`)
        * `contains` (`bool`)
        * `continent` (`bool`)
        * `countryCode` (`bool`)
        * `countryName` (`bool`)
        * `cpuUsage` (`bool`)
        * `deviceMake` (`bool`)
        * `deviceModel` (`bool`)
        * `domain` (`bool`)
        * `endsWith` (`bool`)
        * `equals` (`bool`)
        * `expiry` (`bool`)
        * `extension` (`bool`)
        * `external` (`bool`)
        * `geoip` (`bool`)
        * `greater` (`bool`)
        * `greaterOrEqual` (`bool`)
        * `host` (`bool`)
        * `httpBasicAuth` (`bool`)
        * `httpCookie` (`bool`)
        * `httpHeader` (`bool`)
        * `httpHost` (`bool`)
        * `httpMethod` (`bool`)
        * `httpReferer` (`bool`)
        * `httpSetCookie` (`bool`)
        * `httpStatus` (`bool`)
        * `httpUri` (`bool`)
        * `httpUserAgent` (`bool`)
        * `httpVersion` (`bool`)
        * `index` (`float`)
        * `internal` (`bool`)
        * `isp` (`bool`)
        * `last15secs` (`bool`)
        * `last1min` (`bool`)
        * `last5mins` (`bool`)
        * `less` (`bool`)
        * `lessOrEqual` (`bool`)
        * `local` (`bool`)
        * `major` (`bool`)
        * `matches` (`bool`)
        * `minor` (`bool`)
        * `missing` (`bool`)
        * `mss` (`bool`)
        * `not` (`bool`)
        * `org` (`bool`)
        * `password` (`bool`)
        * `path` (`bool`)
        * `pathSegment` (`bool`)
        * `port` (`bool`)
        * `present` (`bool`)
        * `protocol` (`bool`)
        * `queryParameter` (`bool`)
        * `queryString` (`bool`)
        * `regionCode` (`bool`)
        * `regionName` (`bool`)
        * `remote` (`bool`)
        * `request` (`bool`)
        * `response` (`bool`)
        * `routeDomain` (`bool`)
        * `rtt` (`bool`)
        * `scheme` (`bool`)
        * `serverName` (`bool`)
        * `sslCert` (`bool`)
        * `sslClientHello` (`bool`)
        * `sslExtension` (`bool`)
        * `sslServerHandshake` (`bool`)
        * `sslServerHello` (`bool`)
        * `startsWith` (`bool`)
        * `tcp` (`bool`)
        * `text` (`bool`)
        * `tmName` (`str`) - If Rule is used then you need to provide the tm_name it can be any value
        * `unnamedQueryParameter` (`bool`)
        * `userAgentToken` (`bool`)
        * `username` (`bool`)
        * `value` (`bool`)
        * `values` (`list`)
        * `version` (`bool`)
        * `vlan` (`bool`)
        * `vlanId` (`bool`)
    
      * `name` (`str`)
    """
    strategy: pulumi.Output[str]
    """
    Specifies the match strategy
    """
    def __init__(__self__, resource_name, opts=None, controls=None, name=None, published_copy=None, requires=None, rules=None, strategy=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.Policy` Configures Virtual Server
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] controls: Specifies the controls
        :param pulumi.Input[str] published_copy: If you want to publish the policy else it will be deployed in Drafts mode.
        :param pulumi.Input[list] requires: Specifies the protocol
        :param pulumi.Input[list] rules: Rules can be applied using the policy
        :param pulumi.Input[str] strategy: Specifies the match strategy
        
        The **rules** object supports the following:
        
          * `actions` (`pulumi.Input[list]`)
        
            * `app_service` (`pulumi.Input[str]`)
            * `application` (`pulumi.Input[str]`)
            * `asm` (`pulumi.Input[bool]`)
            * `avr` (`pulumi.Input[bool]`)
            * `cache` (`pulumi.Input[bool]`)
            * `carp` (`pulumi.Input[bool]`)
            * `category` (`pulumi.Input[str]`)
            * `classify` (`pulumi.Input[bool]`)
            * `clonePool` (`pulumi.Input[str]`)
            * `code` (`pulumi.Input[float]`)
            * `compress` (`pulumi.Input[bool]`)
            * `content` (`pulumi.Input[str]`)
            * `cookieHash` (`pulumi.Input[bool]`)
            * `cookieInsert` (`pulumi.Input[bool]`)
            * `cookiePassive` (`pulumi.Input[bool]`)
            * `cookieRewrite` (`pulumi.Input[bool]`)
            * `decompress` (`pulumi.Input[bool]`)
            * `defer` (`pulumi.Input[bool]`)
            * `destinationAddress` (`pulumi.Input[bool]`)
            * `disable` (`pulumi.Input[bool]`)
            * `domain` (`pulumi.Input[str]`)
            * `enable` (`pulumi.Input[bool]`)
            * `expiry` (`pulumi.Input[str]`)
            * `expirySecs` (`pulumi.Input[float]`)
            * `expression` (`pulumi.Input[str]`)
            * `extension` (`pulumi.Input[str]`)
            * `facility` (`pulumi.Input[str]`)
            * `forward` (`pulumi.Input[bool]`) - This action will affect forwarding.
            * `fromProfile` (`pulumi.Input[str]`)
            * `hash` (`pulumi.Input[bool]`)
            * `host` (`pulumi.Input[str]`)
            * `http` (`pulumi.Input[bool]`)
            * `httpBasicAuth` (`pulumi.Input[bool]`)
            * `httpCookie` (`pulumi.Input[bool]`)
            * `httpHeader` (`pulumi.Input[bool]`)
            * `httpHost` (`pulumi.Input[bool]`)
            * `httpReferer` (`pulumi.Input[bool]`)
            * `httpReply` (`pulumi.Input[bool]`)
            * `httpSetCookie` (`pulumi.Input[bool]`)
            * `httpUri` (`pulumi.Input[bool]`)
            * `ifile` (`pulumi.Input[str]`)
            * `insert` (`pulumi.Input[bool]`)
            * `internalVirtual` (`pulumi.Input[str]`)
            * `ipAddress` (`pulumi.Input[str]`)
            * `key` (`pulumi.Input[str]`)
            * `l7dos` (`pulumi.Input[bool]`)
            * `length` (`pulumi.Input[float]`)
            * `location` (`pulumi.Input[str]`)
            * `log` (`pulumi.Input[bool]`)
            * `ltmPolicy` (`pulumi.Input[bool]`)
            * `member` (`pulumi.Input[str]`)
            * `message` (`pulumi.Input[str]`)
            * `netmask` (`pulumi.Input[str]`)
            * `nexthop` (`pulumi.Input[str]`)
            * `node` (`pulumi.Input[str]`)
            * `offset` (`pulumi.Input[float]`)
            * `path` (`pulumi.Input[str]`)
            * `pem` (`pulumi.Input[bool]`)
            * `persist` (`pulumi.Input[bool]`)
            * `pin` (`pulumi.Input[bool]`)
            * `policy` (`pulumi.Input[str]`)
            * `pool` (`pulumi.Input[str]`) - This action will direct the stream to this pool.
            * `port` (`pulumi.Input[float]`)
            * `priority` (`pulumi.Input[str]`)
            * `profile` (`pulumi.Input[str]`)
            * `protocol` (`pulumi.Input[str]`)
            * `queryString` (`pulumi.Input[str]`)
            * `rateclass` (`pulumi.Input[str]`)
            * `redirect` (`pulumi.Input[bool]`)
            * `remove` (`pulumi.Input[bool]`)
            * `replace` (`pulumi.Input[bool]`)
            * `request` (`pulumi.Input[bool]`)
            * `requestAdapt` (`pulumi.Input[bool]`)
            * `reset` (`pulumi.Input[bool]`)
            * `response` (`pulumi.Input[bool]`)
            * `responseAdapt` (`pulumi.Input[bool]`)
            * `scheme` (`pulumi.Input[str]`)
            * `script` (`pulumi.Input[str]`)
            * `select` (`pulumi.Input[bool]`)
            * `serverSsl` (`pulumi.Input[bool]`)
            * `setVariable` (`pulumi.Input[bool]`)
            * `snat` (`pulumi.Input[str]`)
            * `snatpool` (`pulumi.Input[str]`)
            * `sourceAddress` (`pulumi.Input[bool]`)
            * `sslClientHello` (`pulumi.Input[bool]`)
            * `sslServerHandshake` (`pulumi.Input[bool]`)
            * `sslServerHello` (`pulumi.Input[bool]`)
            * `sslSessionId` (`pulumi.Input[bool]`)
            * `status` (`pulumi.Input[float]`)
            * `tcl` (`pulumi.Input[bool]`)
            * `tcpNagle` (`pulumi.Input[bool]`)
            * `text` (`pulumi.Input[str]`)
            * `timeout` (`pulumi.Input[float]`)
            * `tmName` (`pulumi.Input[str]`) - If Rule is used then you need to provide the tm_name it can be any value
            * `uie` (`pulumi.Input[bool]`)
            * `universal` (`pulumi.Input[bool]`)
            * `value` (`pulumi.Input[str]`)
            * `virtual` (`pulumi.Input[str]`)
            * `vlan` (`pulumi.Input[str]`)
            * `vlanId` (`pulumi.Input[float]`)
            * `wam` (`pulumi.Input[bool]`)
            * `write` (`pulumi.Input[bool]`)
        
          * `conditions` (`pulumi.Input[list]`)
        
            * `address` (`pulumi.Input[bool]`)
            * `all` (`pulumi.Input[bool]`)
            * `app_service` (`pulumi.Input[str]`)
            * `browserType` (`pulumi.Input[bool]`)
            * `browserVersion` (`pulumi.Input[bool]`)
            * `caseInsensitive` (`pulumi.Input[bool]`)
            * `caseSensitive` (`pulumi.Input[bool]`)
            * `cipher` (`pulumi.Input[bool]`)
            * `cipherBits` (`pulumi.Input[bool]`)
            * `clientSsl` (`pulumi.Input[bool]`)
            * `code` (`pulumi.Input[bool]`)
            * `commonName` (`pulumi.Input[bool]`)
            * `contains` (`pulumi.Input[bool]`)
            * `continent` (`pulumi.Input[bool]`)
            * `countryCode` (`pulumi.Input[bool]`)
            * `countryName` (`pulumi.Input[bool]`)
            * `cpuUsage` (`pulumi.Input[bool]`)
            * `deviceMake` (`pulumi.Input[bool]`)
            * `deviceModel` (`pulumi.Input[bool]`)
            * `domain` (`pulumi.Input[bool]`)
            * `endsWith` (`pulumi.Input[bool]`)
            * `equals` (`pulumi.Input[bool]`)
            * `expiry` (`pulumi.Input[bool]`)
            * `extension` (`pulumi.Input[bool]`)
            * `external` (`pulumi.Input[bool]`)
            * `geoip` (`pulumi.Input[bool]`)
            * `greater` (`pulumi.Input[bool]`)
            * `greaterOrEqual` (`pulumi.Input[bool]`)
            * `host` (`pulumi.Input[bool]`)
            * `httpBasicAuth` (`pulumi.Input[bool]`)
            * `httpCookie` (`pulumi.Input[bool]`)
            * `httpHeader` (`pulumi.Input[bool]`)
            * `httpHost` (`pulumi.Input[bool]`)
            * `httpMethod` (`pulumi.Input[bool]`)
            * `httpReferer` (`pulumi.Input[bool]`)
            * `httpSetCookie` (`pulumi.Input[bool]`)
            * `httpStatus` (`pulumi.Input[bool]`)
            * `httpUri` (`pulumi.Input[bool]`)
            * `httpUserAgent` (`pulumi.Input[bool]`)
            * `httpVersion` (`pulumi.Input[bool]`)
            * `index` (`pulumi.Input[float]`)
            * `internal` (`pulumi.Input[bool]`)
            * `isp` (`pulumi.Input[bool]`)
            * `last15secs` (`pulumi.Input[bool]`)
            * `last1min` (`pulumi.Input[bool]`)
            * `last5mins` (`pulumi.Input[bool]`)
            * `less` (`pulumi.Input[bool]`)
            * `lessOrEqual` (`pulumi.Input[bool]`)
            * `local` (`pulumi.Input[bool]`)
            * `major` (`pulumi.Input[bool]`)
            * `matches` (`pulumi.Input[bool]`)
            * `minor` (`pulumi.Input[bool]`)
            * `missing` (`pulumi.Input[bool]`)
            * `mss` (`pulumi.Input[bool]`)
            * `not` (`pulumi.Input[bool]`)
            * `org` (`pulumi.Input[bool]`)
            * `password` (`pulumi.Input[bool]`)
            * `path` (`pulumi.Input[bool]`)
            * `pathSegment` (`pulumi.Input[bool]`)
            * `port` (`pulumi.Input[bool]`)
            * `present` (`pulumi.Input[bool]`)
            * `protocol` (`pulumi.Input[bool]`)
            * `queryParameter` (`pulumi.Input[bool]`)
            * `queryString` (`pulumi.Input[bool]`)
            * `regionCode` (`pulumi.Input[bool]`)
            * `regionName` (`pulumi.Input[bool]`)
            * `remote` (`pulumi.Input[bool]`)
            * `request` (`pulumi.Input[bool]`)
            * `response` (`pulumi.Input[bool]`)
            * `routeDomain` (`pulumi.Input[bool]`)
            * `rtt` (`pulumi.Input[bool]`)
            * `scheme` (`pulumi.Input[bool]`)
            * `serverName` (`pulumi.Input[bool]`)
            * `sslCert` (`pulumi.Input[bool]`)
            * `sslClientHello` (`pulumi.Input[bool]`)
            * `sslExtension` (`pulumi.Input[bool]`)
            * `sslServerHandshake` (`pulumi.Input[bool]`)
            * `sslServerHello` (`pulumi.Input[bool]`)
            * `startsWith` (`pulumi.Input[bool]`)
            * `tcp` (`pulumi.Input[bool]`)
            * `text` (`pulumi.Input[bool]`)
            * `tmName` (`pulumi.Input[str]`) - If Rule is used then you need to provide the tm_name it can be any value
            * `unnamedQueryParameter` (`pulumi.Input[bool]`)
            * `userAgentToken` (`pulumi.Input[bool]`)
            * `username` (`pulumi.Input[bool]`)
            * `value` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
            * `version` (`pulumi.Input[bool]`)
            * `vlan` (`pulumi.Input[bool]`)
            * `vlanId` (`pulumi.Input[bool]`)
        
          * `name` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_policy.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['controls'] = controls
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['published_copy'] = published_copy
            __props__['requires'] = requires
            __props__['rules'] = rules
            __props__['strategy'] = strategy
        super(Policy, __self__).__init__(
            'f5bigip:ltm/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, controls=None, name=None, published_copy=None, requires=None, rules=None, strategy=None):
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] controls: Specifies the controls
        :param pulumi.Input[str] published_copy: If you want to publish the policy else it will be deployed in Drafts mode.
        :param pulumi.Input[list] requires: Specifies the protocol
        :param pulumi.Input[list] rules: Rules can be applied using the policy
        :param pulumi.Input[str] strategy: Specifies the match strategy
        
        The **rules** object supports the following:
        
          * `actions` (`pulumi.Input[list]`)
        
            * `app_service` (`pulumi.Input[str]`)
            * `application` (`pulumi.Input[str]`)
            * `asm` (`pulumi.Input[bool]`)
            * `avr` (`pulumi.Input[bool]`)
            * `cache` (`pulumi.Input[bool]`)
            * `carp` (`pulumi.Input[bool]`)
            * `category` (`pulumi.Input[str]`)
            * `classify` (`pulumi.Input[bool]`)
            * `clonePool` (`pulumi.Input[str]`)
            * `code` (`pulumi.Input[float]`)
            * `compress` (`pulumi.Input[bool]`)
            * `content` (`pulumi.Input[str]`)
            * `cookieHash` (`pulumi.Input[bool]`)
            * `cookieInsert` (`pulumi.Input[bool]`)
            * `cookiePassive` (`pulumi.Input[bool]`)
            * `cookieRewrite` (`pulumi.Input[bool]`)
            * `decompress` (`pulumi.Input[bool]`)
            * `defer` (`pulumi.Input[bool]`)
            * `destinationAddress` (`pulumi.Input[bool]`)
            * `disable` (`pulumi.Input[bool]`)
            * `domain` (`pulumi.Input[str]`)
            * `enable` (`pulumi.Input[bool]`)
            * `expiry` (`pulumi.Input[str]`)
            * `expirySecs` (`pulumi.Input[float]`)
            * `expression` (`pulumi.Input[str]`)
            * `extension` (`pulumi.Input[str]`)
            * `facility` (`pulumi.Input[str]`)
            * `forward` (`pulumi.Input[bool]`) - This action will affect forwarding.
            * `fromProfile` (`pulumi.Input[str]`)
            * `hash` (`pulumi.Input[bool]`)
            * `host` (`pulumi.Input[str]`)
            * `http` (`pulumi.Input[bool]`)
            * `httpBasicAuth` (`pulumi.Input[bool]`)
            * `httpCookie` (`pulumi.Input[bool]`)
            * `httpHeader` (`pulumi.Input[bool]`)
            * `httpHost` (`pulumi.Input[bool]`)
            * `httpReferer` (`pulumi.Input[bool]`)
            * `httpReply` (`pulumi.Input[bool]`)
            * `httpSetCookie` (`pulumi.Input[bool]`)
            * `httpUri` (`pulumi.Input[bool]`)
            * `ifile` (`pulumi.Input[str]`)
            * `insert` (`pulumi.Input[bool]`)
            * `internalVirtual` (`pulumi.Input[str]`)
            * `ipAddress` (`pulumi.Input[str]`)
            * `key` (`pulumi.Input[str]`)
            * `l7dos` (`pulumi.Input[bool]`)
            * `length` (`pulumi.Input[float]`)
            * `location` (`pulumi.Input[str]`)
            * `log` (`pulumi.Input[bool]`)
            * `ltmPolicy` (`pulumi.Input[bool]`)
            * `member` (`pulumi.Input[str]`)
            * `message` (`pulumi.Input[str]`)
            * `netmask` (`pulumi.Input[str]`)
            * `nexthop` (`pulumi.Input[str]`)
            * `node` (`pulumi.Input[str]`)
            * `offset` (`pulumi.Input[float]`)
            * `path` (`pulumi.Input[str]`)
            * `pem` (`pulumi.Input[bool]`)
            * `persist` (`pulumi.Input[bool]`)
            * `pin` (`pulumi.Input[bool]`)
            * `policy` (`pulumi.Input[str]`)
            * `pool` (`pulumi.Input[str]`) - This action will direct the stream to this pool.
            * `port` (`pulumi.Input[float]`)
            * `priority` (`pulumi.Input[str]`)
            * `profile` (`pulumi.Input[str]`)
            * `protocol` (`pulumi.Input[str]`)
            * `queryString` (`pulumi.Input[str]`)
            * `rateclass` (`pulumi.Input[str]`)
            * `redirect` (`pulumi.Input[bool]`)
            * `remove` (`pulumi.Input[bool]`)
            * `replace` (`pulumi.Input[bool]`)
            * `request` (`pulumi.Input[bool]`)
            * `requestAdapt` (`pulumi.Input[bool]`)
            * `reset` (`pulumi.Input[bool]`)
            * `response` (`pulumi.Input[bool]`)
            * `responseAdapt` (`pulumi.Input[bool]`)
            * `scheme` (`pulumi.Input[str]`)
            * `script` (`pulumi.Input[str]`)
            * `select` (`pulumi.Input[bool]`)
            * `serverSsl` (`pulumi.Input[bool]`)
            * `setVariable` (`pulumi.Input[bool]`)
            * `snat` (`pulumi.Input[str]`)
            * `snatpool` (`pulumi.Input[str]`)
            * `sourceAddress` (`pulumi.Input[bool]`)
            * `sslClientHello` (`pulumi.Input[bool]`)
            * `sslServerHandshake` (`pulumi.Input[bool]`)
            * `sslServerHello` (`pulumi.Input[bool]`)
            * `sslSessionId` (`pulumi.Input[bool]`)
            * `status` (`pulumi.Input[float]`)
            * `tcl` (`pulumi.Input[bool]`)
            * `tcpNagle` (`pulumi.Input[bool]`)
            * `text` (`pulumi.Input[str]`)
            * `timeout` (`pulumi.Input[float]`)
            * `tmName` (`pulumi.Input[str]`) - If Rule is used then you need to provide the tm_name it can be any value
            * `uie` (`pulumi.Input[bool]`)
            * `universal` (`pulumi.Input[bool]`)
            * `value` (`pulumi.Input[str]`)
            * `virtual` (`pulumi.Input[str]`)
            * `vlan` (`pulumi.Input[str]`)
            * `vlanId` (`pulumi.Input[float]`)
            * `wam` (`pulumi.Input[bool]`)
            * `write` (`pulumi.Input[bool]`)
        
          * `conditions` (`pulumi.Input[list]`)
        
            * `address` (`pulumi.Input[bool]`)
            * `all` (`pulumi.Input[bool]`)
            * `app_service` (`pulumi.Input[str]`)
            * `browserType` (`pulumi.Input[bool]`)
            * `browserVersion` (`pulumi.Input[bool]`)
            * `caseInsensitive` (`pulumi.Input[bool]`)
            * `caseSensitive` (`pulumi.Input[bool]`)
            * `cipher` (`pulumi.Input[bool]`)
            * `cipherBits` (`pulumi.Input[bool]`)
            * `clientSsl` (`pulumi.Input[bool]`)
            * `code` (`pulumi.Input[bool]`)
            * `commonName` (`pulumi.Input[bool]`)
            * `contains` (`pulumi.Input[bool]`)
            * `continent` (`pulumi.Input[bool]`)
            * `countryCode` (`pulumi.Input[bool]`)
            * `countryName` (`pulumi.Input[bool]`)
            * `cpuUsage` (`pulumi.Input[bool]`)
            * `deviceMake` (`pulumi.Input[bool]`)
            * `deviceModel` (`pulumi.Input[bool]`)
            * `domain` (`pulumi.Input[bool]`)
            * `endsWith` (`pulumi.Input[bool]`)
            * `equals` (`pulumi.Input[bool]`)
            * `expiry` (`pulumi.Input[bool]`)
            * `extension` (`pulumi.Input[bool]`)
            * `external` (`pulumi.Input[bool]`)
            * `geoip` (`pulumi.Input[bool]`)
            * `greater` (`pulumi.Input[bool]`)
            * `greaterOrEqual` (`pulumi.Input[bool]`)
            * `host` (`pulumi.Input[bool]`)
            * `httpBasicAuth` (`pulumi.Input[bool]`)
            * `httpCookie` (`pulumi.Input[bool]`)
            * `httpHeader` (`pulumi.Input[bool]`)
            * `httpHost` (`pulumi.Input[bool]`)
            * `httpMethod` (`pulumi.Input[bool]`)
            * `httpReferer` (`pulumi.Input[bool]`)
            * `httpSetCookie` (`pulumi.Input[bool]`)
            * `httpStatus` (`pulumi.Input[bool]`)
            * `httpUri` (`pulumi.Input[bool]`)
            * `httpUserAgent` (`pulumi.Input[bool]`)
            * `httpVersion` (`pulumi.Input[bool]`)
            * `index` (`pulumi.Input[float]`)
            * `internal` (`pulumi.Input[bool]`)
            * `isp` (`pulumi.Input[bool]`)
            * `last15secs` (`pulumi.Input[bool]`)
            * `last1min` (`pulumi.Input[bool]`)
            * `last5mins` (`pulumi.Input[bool]`)
            * `less` (`pulumi.Input[bool]`)
            * `lessOrEqual` (`pulumi.Input[bool]`)
            * `local` (`pulumi.Input[bool]`)
            * `major` (`pulumi.Input[bool]`)
            * `matches` (`pulumi.Input[bool]`)
            * `minor` (`pulumi.Input[bool]`)
            * `missing` (`pulumi.Input[bool]`)
            * `mss` (`pulumi.Input[bool]`)
            * `not` (`pulumi.Input[bool]`)
            * `org` (`pulumi.Input[bool]`)
            * `password` (`pulumi.Input[bool]`)
            * `path` (`pulumi.Input[bool]`)
            * `pathSegment` (`pulumi.Input[bool]`)
            * `port` (`pulumi.Input[bool]`)
            * `present` (`pulumi.Input[bool]`)
            * `protocol` (`pulumi.Input[bool]`)
            * `queryParameter` (`pulumi.Input[bool]`)
            * `queryString` (`pulumi.Input[bool]`)
            * `regionCode` (`pulumi.Input[bool]`)
            * `regionName` (`pulumi.Input[bool]`)
            * `remote` (`pulumi.Input[bool]`)
            * `request` (`pulumi.Input[bool]`)
            * `response` (`pulumi.Input[bool]`)
            * `routeDomain` (`pulumi.Input[bool]`)
            * `rtt` (`pulumi.Input[bool]`)
            * `scheme` (`pulumi.Input[bool]`)
            * `serverName` (`pulumi.Input[bool]`)
            * `sslCert` (`pulumi.Input[bool]`)
            * `sslClientHello` (`pulumi.Input[bool]`)
            * `sslExtension` (`pulumi.Input[bool]`)
            * `sslServerHandshake` (`pulumi.Input[bool]`)
            * `sslServerHello` (`pulumi.Input[bool]`)
            * `startsWith` (`pulumi.Input[bool]`)
            * `tcp` (`pulumi.Input[bool]`)
            * `text` (`pulumi.Input[bool]`)
            * `tmName` (`pulumi.Input[str]`) - If Rule is used then you need to provide the tm_name it can be any value
            * `unnamedQueryParameter` (`pulumi.Input[bool]`)
            * `userAgentToken` (`pulumi.Input[bool]`)
            * `username` (`pulumi.Input[bool]`)
            * `value` (`pulumi.Input[bool]`)
            * `values` (`pulumi.Input[list]`)
            * `version` (`pulumi.Input[bool]`)
            * `vlan` (`pulumi.Input[bool]`)
            * `vlanId` (`pulumi.Input[bool]`)
        
          * `name` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_policy.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["controls"] = controls
        __props__["name"] = name
        __props__["published_copy"] = published_copy
        __props__["requires"] = requires
        __props__["rules"] = rules
        __props__["strategy"] = strategy
        return Policy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class IApp(pulumi.CustomResource):
    description: pulumi.Output[str]
    devicegroup: pulumi.Output[str]
    execute_action: pulumi.Output[str]
    inherited_devicegroup: pulumi.Output[str]
    inherited_traffic_group: pulumi.Output[str]
    jsonfile: pulumi.Output[str]
    """
    Refer to the Json file which will be deployed on F5 BIG-IP.
    """
    lists: pulumi.Output[list]
    metadatas: pulumi.Output[list]
    name: pulumi.Output[str]
    """
    Name of the iApp.
    """
    partition: pulumi.Output[str]
    strict_updates: pulumi.Output[str]
    tables: pulumi.Output[list]
    template: pulumi.Output[str]
    template_modified: pulumi.Output[str]
    template_prerequisite_errors: pulumi.Output[str]
    traffic_group: pulumi.Output[str]
    variables: pulumi.Output[list]
    def __init__(__self__, resource_name, opts=None, description=None, devicegroup=None, execute_action=None, inherited_devicegroup=None, inherited_traffic_group=None, jsonfile=None, lists=None, metadatas=None, name=None, partition=None, strict_updates=None, tables=None, template=None, template_modified=None, template_prerequisite_errors=None, traffic_group=None, variables=None, __props__=None, __name__=None, __opts__=None):
        """
        `sys.IApp` resource helps you to deploy Application Services template that can be used to automate and orchestrate Layer 4-7 applications service deployments using F5 Network.  
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[str] name: Name of the iApp.
        
        The **lists** object supports the following:
        
          * `encrypted` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        
        The **metadatas** object supports the following:
        
          * `persists` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        
        The **tables** object supports the following:
        
          * `columnNames` (`pulumi.Input[list]`)
          * `encryptedColumns` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the iApp.
          * `rows` (`pulumi.Input[list]`)
        
            * `rows` (`pulumi.Input[list]`)
        
        The **variables** object supports the following:
        
          * `encrypted` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the iApp.
          * `value` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_iapp.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['devicegroup'] = devicegroup
            __props__['execute_action'] = execute_action
            __props__['inherited_devicegroup'] = inherited_devicegroup
            __props__['inherited_traffic_group'] = inherited_traffic_group
            __props__['jsonfile'] = jsonfile
            __props__['lists'] = lists
            __props__['metadatas'] = metadatas
            __props__['name'] = name
            __props__['partition'] = partition
            __props__['strict_updates'] = strict_updates
            __props__['tables'] = tables
            __props__['template'] = template
            __props__['template_modified'] = template_modified
            __props__['template_prerequisite_errors'] = template_prerequisite_errors
            __props__['traffic_group'] = traffic_group
            __props__['variables'] = variables
        super(IApp, __self__).__init__(
            'f5bigip:sys/iApp:IApp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, devicegroup=None, execute_action=None, inherited_devicegroup=None, inherited_traffic_group=None, jsonfile=None, lists=None, metadatas=None, name=None, partition=None, strict_updates=None, tables=None, template=None, template_modified=None, template_prerequisite_errors=None, traffic_group=None, variables=None):
        """
        Get an existing IApp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] jsonfile: Refer to the Json file which will be deployed on F5 BIG-IP.
        :param pulumi.Input[str] name: Name of the iApp.
        
        The **lists** object supports the following:
        
          * `encrypted` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        
        The **metadatas** object supports the following:
        
          * `persists` (`pulumi.Input[str]`)
          * `value` (`pulumi.Input[str]`)
        
        The **tables** object supports the following:
        
          * `columnNames` (`pulumi.Input[list]`)
          * `encryptedColumns` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the iApp.
          * `rows` (`pulumi.Input[list]`)
        
            * `rows` (`pulumi.Input[list]`)
        
        The **variables** object supports the following:
        
          * `encrypted` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the iApp.
          * `value` (`pulumi.Input[str]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_iapp.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["description"] = description
        __props__["devicegroup"] = devicegroup
        __props__["execute_action"] = execute_action
        __props__["inherited_devicegroup"] = inherited_devicegroup
        __props__["inherited_traffic_group"] = inherited_traffic_group
        __props__["jsonfile"] = jsonfile
        __props__["lists"] = lists
        __props__["metadatas"] = metadatas
        __props__["name"] = name
        __props__["partition"] = partition
        __props__["strict_updates"] = strict_updates
        __props__["tables"] = tables
        __props__["template"] = template
        __props__["template_modified"] = template_modified
        __props__["template_prerequisite_errors"] = template_prerequisite_errors
        __props__["traffic_group"] = traffic_group
        __props__["variables"] = variables
        return IApp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Vlan(pulumi.CustomResource):
    interfaces: pulumi.Output[list]
    """
    Specifies which interfaces you want this VLAN to use for traffic management.
    
      * `tagged` (`bool`) - Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
      * `vlanport` (`str`) - Physical or virtual port used for traffic
    """
    name: pulumi.Output[str]
    """
    Name of the vlan
    """
    tag: pulumi.Output[float]
    """
    Specifies a number that the system adds into the header of any frame passing through the VLAN.
    """
    def __init__(__self__, resource_name, opts=None, interfaces=None, name=None, tag=None, __props__=None, __name__=None, __opts__=None):
        """
        `net.Vlan` Manages a vlan configuration
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[float] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        
        The **interfaces** object supports the following:
        
          * `tagged` (`pulumi.Input[bool]`) - Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
          * `vlanport` (`pulumi.Input[str]`) - Physical or virtual port used for traffic

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/net_vlan.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['interfaces'] = interfaces
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['tag'] = tag
        super(Vlan, __self__).__init__(
            'f5bigip:net/vlan:Vlan',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, interfaces=None, name=None, tag=None):
        """
        Get an existing Vlan resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] interfaces: Specifies which interfaces you want this VLAN to use for traffic management.
        :param pulumi.Input[str] name: Name of the vlan
        :param pulumi.Input[float] tag: Specifies a number that the system adds into the header of any frame passing through the VLAN.
        
        The **interfaces** object supports the following:
        
          * `tagged` (`pulumi.Input[bool]`) - Specifies a list of tagged interfaces or trunks associated with this VLAN. Note that you can associate tagged interfaces or trunks with any number of VLANs.
          * `vlanport` (`pulumi.Input[str]`) - Physical or virtual port used for traffic

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/net_vlan.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["interfaces"] = interfaces
        __props__["name"] = name
        __props__["tag"] = tag
        return Vlan(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ProfileHttpCompress(pulumi.CustomResource):
    content_type_excludes: pulumi.Output[list]
    """
    Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
    """
    content_type_includes: pulumi.Output[list]
    """
    Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
    """
    defaults_from: pulumi.Output[str]
    """
    Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
    """
    name: pulumi.Output[str]
    """
    Name of the profile_httpcompress
    """
    uri_excludes: pulumi.Output[list]
    """
    Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
    """
    uri_includes: pulumi.Output[list]
    """
    Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.
    """
    def __init__(__self__, resource_name, opts=None, content_type_excludes=None, content_type_includes=None, defaults_from=None, name=None, uri_excludes=None, uri_includes=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.ProfileHttpCompress`  Virtual server HTTP compression profile configuration
        
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[list] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] name: Name of the profile_httpcompress
        :param pulumi.Input[list] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[list] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_httpcompress.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['content_type_excludes'] = content_type_excludes
            __props__['content_type_includes'] = content_type_includes
            __props__['defaults_from'] = defaults_from
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['uri_excludes'] = uri_excludes
            __props__['uri_includes'] = uri_includes
        super(ProfileHttpCompress, __self__).__init__(
            'f5bigip:ltm/profileHttpCompress:ProfileHttpCompress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, content_type_excludes=None, content_type_includes=None, defaults_from=None, name=None, uri_excludes=None, uri_includes=None):
        """
        Get an existing ProfileHttpCompress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] content_type_excludes: Excludes a specified list of content types from compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[list] content_type_includes: Specifies a list of content types for compression of HTTP Content-Type responses. Use a string list to specify a list of content types you want to compress.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] name: Name of the profile_httpcompress
        :param pulumi.Input[list] uri_excludes: Disables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you do not want to compress.
        :param pulumi.Input[list] uri_includes: Enables compression on a specified list of HTTP Request-URI responses. Use a regular expression to specify a list of URIs you want to compress.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_httpcompress.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["content_type_excludes"] = content_type_excludes
        __props__["content_type_includes"] = content_type_includes
        __props__["defaults_from"] = defaults_from
        __props__["name"] = name
        __props__["uri_excludes"] = uri_excludes
        __props__["uri_includes"] = uri_includes
        return ProfileHttpCompress(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Dns(pulumi.CustomResource):
    description: pulumi.Output[str]
    name_servers: pulumi.Output[list]
    """
    Name or IP address of the DNS server
    """
    number_of_dots: pulumi.Output[float]
    """
    Configures the number of dots needed in a name before an initial absolute query will be made.
    """
    searches: pulumi.Output[list]
    """
    Specify what domains you want to search
    """
    def __init__(__self__, resource_name, opts=None, description=None, name_servers=None, number_of_dots=None, searches=None, __props__=None, __name__=None, __opts__=None):
        """
        `sys.Dns` Configures DNS server on F5 BIG-IP
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] name_servers: Name or IP address of the DNS server
        :param pulumi.Input[float] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[list] searches: Specify what domains you want to search

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_dns.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if description is None:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            __props__['name_servers'] = name_servers
            __props__['number_of_dots'] = number_of_dots
            __props__['searches'] = searches
        super(Dns, __self__).__init__(
            'f5bigip:sys/dns:Dns',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, name_servers=None, number_of_dots=None, searches=None):
        """
        Get an existing Dns resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] name_servers: Name or IP address of the DNS server
        :param pulumi.Input[float] number_of_dots: Configures the number of dots needed in a name before an initial absolute query will be made.
        :param pulumi.Input[list] searches: Specify what domains you want to search

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_dns.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["description"] = description
        __props__["name_servers"] = name_servers
        __props__["number_of_dots"] = number_of_dots
        __props__["searches"] = searches
        return Dns(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Node(pulumi.CustomResource):
    address: pulumi.Output[str]
    """
    IP or hostname of the node
    """
    connection_limit: pulumi.Output[float]
    """
    Specifies the maximum number of connections allowed for the node or node address.
    """
    description: pulumi.Output[str]
    """
    User-defined description give ltm_node
    """
    dynamic_ratio: pulumi.Output[float]
    """
    Specifies the fixed ratio value used for a node during ratio load balancing.
    """
    fqdn: pulumi.Output[dict]
    monitor: pulumi.Output[str]
    """
    specifies the name of the monitor or monitor rule that you want to associate with the node.
    """
    name: pulumi.Output[str]
    """
    Name of the node
    """
    rate_limit: pulumi.Output[str]
    ratio: pulumi.Output[float]
    state: pulumi.Output[str]
    """
    Default is "user-up" you can set to "user-down" if you want to disable
    """
    def __init__(__self__, resource_name, opts=None, address=None, connection_limit=None, description=None, dynamic_ratio=None, fqdn=None, monitor=None, name=None, rate_limit=None, ratio=None, state=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.Node` Manages a node configuration
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[float] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[float] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
        
        The **fqdn** object supports the following:
        
          * `addressFamily` (`pulumi.Input[str]`) - Specifies the node's address family. The default is 'unspecified', or IP-agnostic. This needs to be specified inside the fqdn (fully qualified domain name).
          * `autopopulate` (`pulumi.Input[str]`)
          * `downinterval` (`pulumi.Input[float]`)
          * `interval` (`pulumi.Input[str]`) - Specifies the amount of time before sending the next DNS query. Default is 3600. This needs to be specified inside the fqdn (fully qualified domain name).
          * `name` (`pulumi.Input[str]`) - Name of the node

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_node.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if address is None:
                raise TypeError("Missing required property 'address'")
            __props__['address'] = address
            __props__['connection_limit'] = connection_limit
            __props__['description'] = description
            __props__['dynamic_ratio'] = dynamic_ratio
            __props__['fqdn'] = fqdn
            __props__['monitor'] = monitor
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['rate_limit'] = rate_limit
            __props__['ratio'] = ratio
            __props__['state'] = state
        super(Node, __self__).__init__(
            'f5bigip:ltm/node:Node',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, address=None, connection_limit=None, description=None, dynamic_ratio=None, fqdn=None, monitor=None, name=None, rate_limit=None, ratio=None, state=None):
        """
        Get an existing Node resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address: IP or hostname of the node
        :param pulumi.Input[float] connection_limit: Specifies the maximum number of connections allowed for the node or node address.
        :param pulumi.Input[str] description: User-defined description give ltm_node
        :param pulumi.Input[float] dynamic_ratio: Specifies the fixed ratio value used for a node during ratio load balancing.
        :param pulumi.Input[str] monitor: specifies the name of the monitor or monitor rule that you want to associate with the node.
        :param pulumi.Input[str] name: Name of the node
        :param pulumi.Input[str] state: Default is "user-up" you can set to "user-down" if you want to disable
        
        The **fqdn** object supports the following:
        
          * `addressFamily` (`pulumi.Input[str]`) - Specifies the node's address family. The default is 'unspecified', or IP-agnostic. This needs to be specified inside the fqdn (fully qualified domain name).
          * `autopopulate` (`pulumi.Input[str]`)
          * `downinterval` (`pulumi.Input[float]`)
          * `interval` (`pulumi.Input[str]`) - Specifies the amount of time before sending the next DNS query. Default is 3600. This needs to be specified inside the fqdn (fully qualified domain name).
          * `name` (`pulumi.Input[str]`) - Name of the node

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_node.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["address"] = address
        __props__["connection_limit"] = connection_limit
        __props__["description"] = description
        __props__["dynamic_ratio"] = dynamic_ratio
        __props__["fqdn"] = fqdn
        __props__["monitor"] = monitor
        __props__["name"] = name
        __props__["rate_limit"] = rate_limit
        __props__["ratio"] = ratio
        __props__["state"] = state
        return Node(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "accept_xff": "acceptXff",
    "activation_modes": "activationModes",
    "adaptive_limit": "adaptiveLimit",
    "advertize_route": "advertizeRoute",
    "allow_nat": "allowNat",
    "allow_snat": "allowSnat",
    "always_send": "alwaysSend",
    "app_service": "appService",
    "auth_passwordencrypted": "authPasswordencrypted",
    "auth_protocol": "authProtocol",
    "auto_delete": "autoDelete",
    "auto_sync": "autoSync",
    "basic_auth_realm": "basicAuthRealm",
    "client_profiles": "clientProfiles",
    "client_timeout": "clientTimeout",
    "close_wait_timeout": "closeWaitTimeout",
    "concurrent_streams_per_connection": "concurrentStreamsPerConnection",
    "configsync_ip": "configsyncIp",
    "conn_limit": "connLimit",
    "connection_idle_timeout": "connectionIdleTimeout",
    "connection_limit": "connectionLimit",
    "connpool_maxreuse": "connpoolMaxreuse",
    "connpool_maxsize": "connpoolMaxsize",
    "connpool_minsize": "connpoolMinsize",
    "connpool_replenish": "connpoolReplenish",
    "connpool_step": "connpoolStep",
    "connpoolidle_timeoutoverride": "connpoolidleTimeoutoverride",
    "content_type_excludes": "contentTypeExcludes",
    "content_type_includes": "contentTypeIncludes",
    "cookie_encryption": "cookieEncryption",
    "cookie_encryption_passphrase": "cookieEncryptionPassphrase",
    "cookie_name": "cookieName",
    "cpu_ratio": "cpuRatio",
    "default_persistence_profile": "defaultPersistenceProfile",
    "defaults_from": "defaultsFrom",
    "deferred_accept": "deferredAccept",
    "disk_ratio": "diskRatio",
    "dynamic_ratio": "dynamicRatio",
    "encrypt_cookie_secret": "encryptCookieSecret",
    "encrypt_cookies": "encryptCookies",
    "engine_id": "engineId",
    "execute_action": "executeAction",
    "explicitflow_migration": "explicitflowMigration",
    "fallback_host": "fallbackHost",
    "fallback_persistence_profile": "fallbackPersistenceProfile",
    "fallback_status_codes": "fallbackStatusCodes",
    "fast_open": "fastOpen",
    "finwait_timeout": "finwaitTimeout",
    "full_load_on_sync": "fullLoadOnSync",
    "full_path": "fullPath",
    "hardware_syncookie": "hardwareSyncookie",
    "hash_algorithm": "hashAlgorithm",
    "hash_length": "hashLength",
    "hash_offset": "hashOffset",
    "head_erase": "headErase",
    "head_insert": "headInsert",
    "header_table_size": "headerTableSize",
    "icmp_echo": "icmpEcho",
    "idle_timeout": "idleTimeout",
    "idle_timeout_override": "idleTimeoutOverride",
    "incremental_config": "incrementalConfig",
    "inherited_devicegroup": "inheritedDevicegroup",
    "inherited_traffic_group": "inheritedTrafficGroup",
    "insert_xforwarded_for": "insertXforwardedFor",
    "ip_dscp": "ipDscp",
    "ip_protocol": "ipProtocol",
    "iptos_toclient": "iptosToclient",
    "iptos_toserver": "iptosToserver",
    "keepalive_interval": "keepaliveInterval",
    "load_balancing_mode": "loadBalancingMode",
    "login_ref": "loginRef",
    "lws_separator": "lwsSeparator",
    "manual_resume": "manualResume",
    "map_proxies": "mapProxies",
    "match_across_pools": "matchAcrossPools",
    "match_across_services": "matchAcrossServices",
    "match_across_virtuals": "matchAcrossVirtuals",
    "max_age": "maxAge",
    "max_reuse": "maxReuse",
    "max_size": "maxSize",
    "maxheader_size": "maxheaderSize",
    "memory_ratio": "memoryRatio",
    "mirror_ip": "mirrorIp",
    "mirror_secondary_ip": "mirrorSecondaryIp",
    "name_servers": "nameServers",
    "network_failover": "networkFailover",
    "number_of_dots": "numberOfDots",
    "oneconnect_transformations": "oneconnectTransformations",
    "override_conn_limit": "overrideConnLimit",
    "persistence_profiles": "persistenceProfiles",
    "privacy_password": "privacyPassword",
    "privacy_password_encrypted": "privacyPasswordEncrypted",
    "privacy_protocol": "privacyProtocol",
    "proxy_type": "proxyType",
    "published_copy": "publishedCopy",
    "rate_limit": "rateLimit",
    "receive_disable": "receiveDisable",
    "redirect_rewrite": "redirectRewrite",
    "registration_key": "registrationKey",
    "request_chunking": "requestChunking",
    "reselect_tries": "reselectTries",
    "response_chunking": "responseChunking",
    "response_headers_permitteds": "responseHeadersPermitteds",
    "save_on_auto_sync": "saveOnAutoSync",
    "security_level": "securityLevel",
    "security_name": "securityName",
    "server_agent_name": "serverAgentName",
    "server_profiles": "serverProfiles",
    "service_down_action": "serviceDownAction",
    "share_pools": "sharePools",
    "slow_ramp_time": "slowRampTime",
    "source_address_translation": "sourceAddressTranslation",
    "source_mask": "sourceMask",
    "strict_updates": "strictUpdates",
    "sys_contact": "sysContact",
    "sys_location": "sysLocation",
    "template_modified": "templateModified",
    "template_prerequisite_errors": "templatePrerequisiteErrors",
    "time_until_up": "timeUntilUp",
    "tm_partition": "tmPartition",
    "token_auth": "tokenAuth",
    "traffic_group": "trafficGroup",
    "translate_address": "translateAddress",
    "translate_port": "translatePort",
    "uri_excludes": "uriExcludes",
    "uri_includes": "uriIncludes",
    "via_host_name": "viaHostName",
    "via_request": "viaRequest",
    "via_response": "viaResponse",
    "vlans_enabled": "vlansEnabled",
    "xff_alternative_names": "xffAlternativeNames",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceptXff": "accept_xff",
    "activationModes": "activation_modes",
    "adaptiveLimit": "adaptive_limit",
    "advertizeRoute": "advertize_route",
    "allowNat": "allow_nat",
    "allowSnat": "allow_snat",
    "alwaysSend": "always_send",
    "appService": "app_service",
    "authPasswordencrypted": "auth_passwordencrypted",
    "authProtocol": "auth_protocol",
    "autoDelete": "auto_delete",
    "autoSync": "auto_sync",
    "basicAuthRealm": "basic_auth_realm",
    "clientProfiles": "client_profiles",
    "clientTimeout": "client_timeout",
    "closeWaitTimeout": "close_wait_timeout",
    "concurrentStreamsPerConnection": "concurrent_streams_per_connection",
    "configsyncIp": "configsync_ip",
    "connLimit": "conn_limit",
    "connectionIdleTimeout": "connection_idle_timeout",
    "connectionLimit": "connection_limit",
    "connpoolMaxreuse": "connpool_maxreuse",
    "connpoolMaxsize": "connpool_maxsize",
    "connpoolMinsize": "connpool_minsize",
    "connpoolReplenish": "connpool_replenish",
    "connpoolStep": "connpool_step",
    "connpoolidleTimeoutoverride": "connpoolidle_timeoutoverride",
    "contentTypeExcludes": "content_type_excludes",
    "contentTypeIncludes": "content_type_includes",
    "cookieEncryption": "cookie_encryption",
    "cookieEncryptionPassphrase": "cookie_encryption_passphrase",
    "cookieName": "cookie_name",
    "cpuRatio": "cpu_ratio",
    "defaultPersistenceProfile": "default_persistence_profile",
    "defaultsFrom": "defaults_from",
    "deferredAccept": "deferred_accept",
    "diskRatio": "disk_ratio",
    "dynamicRatio": "dynamic_ratio",
    "encryptCookieSecret": "encrypt_cookie_secret",
    "encryptCookies": "encrypt_cookies",
    "engineId": "engine_id",
    "executeAction": "execute_action",
    "explicitflowMigration": "explicitflow_migration",
    "fallbackHost": "fallback_host",
    "fallbackPersistenceProfile": "fallback_persistence_profile",
    "fallbackStatusCodes": "fallback_status_codes",
    "fastOpen": "fast_open",
    "finwaitTimeout": "finwait_timeout",
    "fullLoadOnSync": "full_load_on_sync",
    "fullPath": "full_path",
    "hardwareSyncookie": "hardware_syncookie",
    "hashAlgorithm": "hash_algorithm",
    "hashLength": "hash_length",
    "hashOffset": "hash_offset",
    "headErase": "head_erase",
    "headInsert": "head_insert",
    "headerTableSize": "header_table_size",
    "icmpEcho": "icmp_echo",
    "idleTimeout": "idle_timeout",
    "idleTimeoutOverride": "idle_timeout_override",
    "incrementalConfig": "incremental_config",
    "inheritedDevicegroup": "inherited_devicegroup",
    "inheritedTrafficGroup": "inherited_traffic_group",
    "insertXforwardedFor": "insert_xforwarded_for",
    "ipDscp": "ip_dscp",
    "ipProtocol": "ip_protocol",
    "iptosToclient": "iptos_toclient",
    "iptosToserver": "iptos_toserver",
    "keepaliveInterval": "keepalive_interval",
    "loadBalancingMode": "load_balancing_mode",
    "loginRef": "login_ref",
    "lwsSeparator": "lws_separator",
    "manualResume": "manual_resume",
    "mapProxies": "map_proxies",
    "matchAcrossPools": "match_across_pools",
    "matchAcrossServices": "match_across_services",
    "matchAcrossVirtuals": "match_across_virtuals",
    "maxAge": "max_age",
    "maxReuse": "max_reuse",
    "maxSize": "max_size",
    "maxheaderSize": "maxheader_size",
    "memoryRatio": "memory_ratio",
    "mirrorIp": "mirror_ip",
    "mirrorSecondaryIp": "mirror_secondary_ip",
    "nameServers": "name_servers",
    "networkFailover": "network_failover",
    "numberOfDots": "number_of_dots",
    "oneconnectTransformations": "oneconnect_transformations",
    "overrideConnLimit": "override_conn_limit",
    "persistenceProfiles": "persistence_profiles",
    "privacyPassword": "privacy_password",
    "privacyPasswordEncrypted": "privacy_password_encrypted",
    "privacyProtocol": "privacy_protocol",
    "proxyType": "proxy_type",
    "publishedCopy": "published_copy",
    "rateLimit": "rate_limit",
    "receiveDisable": "receive_disable",
    "redirectRewrite": "redirect_rewrite",
    "registrationKey": "registration_key",
    "requestChunking": "request_chunking",
    "reselectTries": "reselect_tries",
    "responseChunking": "response_chunking",
    "responseHeadersPermitteds": "response_headers_permitteds",
    "saveOnAutoSync": "save_on_auto_sync",
    "securityLevel": "security_level",
    "securityName": "security_name",
    "serverAgentName": "server_agent_name",
    "serverProfiles": "server_profiles",
    "serviceDownAction": "service_down_action",
    "sharePools": "share_pools",
    "slowRampTime": "slow_ramp_time",
    "sourceAddressTranslation": "source_address_translation",
    "sourceMask": "source_mask",
    "strictUpdates": "strict_updates",
    "sysContact": "sys_contact",
    "sysLocation": "sys_location",
    "templateModified": "template_modified",
    "templatePrerequisiteErrors": "template_prerequisite_errors",
    "timeUntilUp": "time_until_up",
    "tmPartition": "tm_partition",
    "tokenAuth": "token_auth",
    "trafficGroup": "traffic_group",
    "translateAddress": "translate_address",
    "translatePort": "translate_port",
    "uriExcludes": "uri_excludes",
    "uriIncludes": "uri_includes",
    "viaHostName": "via_host_name",
    "viaRequest": "via_request",
    "viaResponse": "via_response",
    "vlansEnabled": "vlans_enabled",
    "xffAlternativeNames": "xff_alternative_names",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Monitor(pulumi.CustomResource):
    adaptive: pulumi.Output[str]
    adaptive_limit: pulumi.Output[float]
    compatibility: pulumi.Output[str]
    """
    Specifies, when enabled, that the SSL options setting (in OpenSSL) is set to ALL. Accepts 'enabled' or 'disabled' values, the default value is 'enabled'.
    """
    defaults_from: pulumi.Output[str]
    destination: pulumi.Output[str]
    """
    Specify an alias address for monitoring
    """
    filename: pulumi.Output[str]
    """
    Specifies the full path and file name of the file that the system attempts to download. The health check is successful if the system can download the file.
    """
    interval: pulumi.Output[float]
    """
    Check interval in seconds
    """
    ip_dscp: pulumi.Output[float]
    manual_resume: pulumi.Output[str]
    mode: pulumi.Output[str]
    """
    Specifies the data transfer process (DTP) mode. The default value is passive. The options are passive (Specifies that the monitor sends a data transfer request to the FTP server. When the FTP server receives the request, the FTP server then initiates and establishes the data connection.) and active (Specifies that the monitor initiates and establishes the data connection with the FTP server.).
    """
    name: pulumi.Output[str]
    """
    Name of the monitor
    """
    parent: pulumi.Output[str]
    """
    Existing LTM monitor to inherit from
    """
    password: pulumi.Output[str]
    receive: pulumi.Output[str]
    """
    Expected response string
    """
    receive_disable: pulumi.Output[str]
    reverse: pulumi.Output[str]
    send: pulumi.Output[str]
    """
    Request string to send
    """
    time_until_up: pulumi.Output[float]
    timeout: pulumi.Output[float]
    """
    Timeout in seconds
    """
    transparent: pulumi.Output[str]
    username: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, adaptive=None, adaptive_limit=None, compatibility=None, defaults_from=None, destination=None, filename=None, interval=None, ip_dscp=None, manual_resume=None, mode=None, name=None, parent=None, password=None, receive=None, receive_disable=None, reverse=None, send=None, time_until_up=None, timeout=None, transparent=None, username=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.Monitor` Configures a custom monitor for use by health checks.
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compatibility: Specifies, when enabled, that the SSL options setting (in OpenSSL) is set to ALL. Accepts 'enabled' or 'disabled' values, the default value is 'enabled'.
        :param pulumi.Input[str] destination: Specify an alias address for monitoring
        :param pulumi.Input[str] filename: Specifies the full path and file name of the file that the system attempts to download. The health check is successful if the system can download the file.
        :param pulumi.Input[float] interval: Check interval in seconds
        :param pulumi.Input[str] mode: Specifies the data transfer process (DTP) mode. The default value is passive. The options are passive (Specifies that the monitor sends a data transfer request to the FTP server. When the FTP server receives the request, the FTP server then initiates and establishes the data connection.) and active (Specifies that the monitor initiates and establishes the data connection with the FTP server.).
        :param pulumi.Input[str] name: Name of the monitor
        :param pulumi.Input[str] parent: Existing LTM monitor to inherit from
        :param pulumi.Input[str] receive: Expected response string
        :param pulumi.Input[str] send: Request string to send
        :param pulumi.Input[float] timeout: Timeout in seconds

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_monitor.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['adaptive'] = adaptive
            __props__['adaptive_limit'] = adaptive_limit
            __props__['compatibility'] = compatibility
            __props__['defaults_from'] = defaults_from
            __props__['destination'] = destination
            __props__['filename'] = filename
            __props__['interval'] = interval
            __props__['ip_dscp'] = ip_dscp
            __props__['manual_resume'] = manual_resume
            __props__['mode'] = mode
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            if parent is None:
                raise TypeError("Missing required property 'parent'")
            __props__['parent'] = parent
            __props__['password'] = password
            __props__['receive'] = receive
            __props__['receive_disable'] = receive_disable
            __props__['reverse'] = reverse
            __props__['send'] = send
            __props__['time_until_up'] = time_until_up
            __props__['timeout'] = timeout
            __props__['transparent'] = transparent
            __props__['username'] = username
        super(Monitor, __self__).__init__(
            'f5bigip:ltm/monitor:Monitor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, adaptive=None, adaptive_limit=None, compatibility=None, defaults_from=None, destination=None, filename=None, interval=None, ip_dscp=None, manual_resume=None, mode=None, name=None, parent=None, password=None, receive=None, receive_disable=None, reverse=None, send=None, time_until_up=None, timeout=None, transparent=None, username=None):
        """
        Get an existing Monitor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compatibility: Specifies, when enabled, that the SSL options setting (in OpenSSL) is set to ALL. Accepts 'enabled' or 'disabled' values, the default value is 'enabled'.
        :param pulumi.Input[str] destination: Specify an alias address for monitoring
        :param pulumi.Input[str] filename: Specifies the full path and file name of the file that the system attempts to download. The health check is successful if the system can download the file.
        :param pulumi.Input[float] interval: Check interval in seconds
        :param pulumi.Input[str] mode: Specifies the data transfer process (DTP) mode. The default value is passive. The options are passive (Specifies that the monitor sends a data transfer request to the FTP server. When the FTP server receives the request, the FTP server then initiates and establishes the data connection.) and active (Specifies that the monitor initiates and establishes the data connection with the FTP server.).
        :param pulumi.Input[str] name: Name of the monitor
        :param pulumi.Input[str] parent: Existing LTM monitor to inherit from
        :param pulumi.Input[str] receive: Expected response string
        :param pulumi.Input[str] send: Request string to send
        :param pulumi.Input[float] timeout: Timeout in seconds

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_monitor.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["adaptive"] = adaptive
        __props__["adaptive_limit"] = adaptive_limit
        __props__["compatibility"] = compatibility
        __props__["defaults_from"] = defaults_from
        __props__["destination"] = destination
        __props__["filename"] = filename
        __props__["interval"] = interval
        __props__["ip_dscp"] = ip_dscp
        __props__["manual_resume"] = manual_resume
        __props__["mode"] = mode
        __props__["name"] = name
        __props__["parent"] = parent
        __props__["password"] = password
        __props__["receive"] = receive
        __props__["receive_disable"] = receive_disable
        __props__["reverse"] = reverse
        __props__["send"] = send
        __props__["time_until_up"] = time_until_up
        __props__["timeout"] = timeout
        __props__["transparent"] = transparent
        __props__["username"] = username
        return Monitor(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class PersistenceProfileSsl(pulumi.CustomResource):
    app_service: pulumi.Output[str]
    defaults_from: pulumi.Output[str]
    match_across_pools: pulumi.Output[str]
    match_across_services: pulumi.Output[str]
    match_across_virtuals: pulumi.Output[str]
    mirror: pulumi.Output[str]
    name: pulumi.Output[str]
    override_conn_limit: pulumi.Output[str]
    timeout: pulumi.Output[float]
    def __init__(__self__, resource_name, opts=None, app_service=None, defaults_from=None, match_across_pools=None, match_across_services=None, match_across_virtuals=None, mirror=None, name=None, override_conn_limit=None, timeout=None, __props__=None, __name__=None, __opts__=None):
        """
        Configures an SSL persistence profile
        
        ## Reference
        
        `name` - (Required) Name of the virtual address
        
        `defaults_from` - (Required) Parent cookie persistence profile
        
        `match_across_pools` (Optional) (enabled or disabled) match across pools with given persistence record
        
        `match_across_services` (Optional) (enabled or disabled) match across services with given persistence record
        
        `match_across_virtuals` (Optional) (enabled or disabled) match across virtual servers with given persistence record
        
        `mirror` (Optional) (enabled or disabled) mirror persistence record
        
        `timeout` (Optional) (enabled or disabled) Timeout for persistence of the session in seconds
        
        `override_conn_limit` (Optional) (enabled or disabled) Enable or dissable pool member connection limits are overridden for persisted clients. Per-virtual connection limits remain hard limits and are not overridden.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_persistence_profile_ssl.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['app_service'] = app_service
            if defaults_from is None:
                raise TypeError("Missing required property 'defaults_from'")
            __props__['defaults_from'] = defaults_from
            __props__['match_across_pools'] = match_across_pools
            __props__['match_across_services'] = match_across_services
            __props__['match_across_virtuals'] = match_across_virtuals
            __props__['mirror'] = mirror
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['override_conn_limit'] = override_conn_limit
            __props__['timeout'] = timeout
        super(PersistenceProfileSsl, __self__).__init__(
            'f5bigip:ltm/persistenceProfileSsl:PersistenceProfileSsl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, app_service=None, defaults_from=None, match_across_pools=None, match_across_services=None, match_across_virtuals=None, mirror=None, name=None, override_conn_limit=None, timeout=None):
        """
        Get an existing PersistenceProfileSsl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_persistence_profile_ssl.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["app_service"] = app_service
        __props__["defaults_from"] = defaults_from
        __props__["match_across_pools"] = match_across_pools
        __props__["match_across_services"] = match_across_services
        __props__["match_across_virtuals"] = match_across_virtuals
        __props__["mirror"] = mirror
        __props__["name"] = name
        __props__["override_conn_limit"] = override_conn_limit
        __props__["timeout"] = timeout
        return PersistenceProfileSsl(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ProfileTcp(pulumi.CustomResource):
    close_wait_timeout: pulumi.Output[float]
    """
    Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
    """
    defaults_from: pulumi.Output[str]
    """
    Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
    """
    deferred_accept: pulumi.Output[str]
    """
    Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
    """
    fast_open: pulumi.Output[str]
    """
    When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet.
    """
    finwait2timeout: pulumi.Output[float]
    """
    Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
    """
    finwait_timeout: pulumi.Output[float]
    """
    Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
    """
    idle_timeout: pulumi.Output[float]
    """
    Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
    """
    keepalive_interval: pulumi.Output[float]
    """
    Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
    """
    name: pulumi.Output[str]
    """
    Name of the profile_tcp
    """
    partition: pulumi.Output[str]
    """
    Displays the administrative partition within which this profile resides
    """
    def __init__(__self__, resource_name, opts=None, close_wait_timeout=None, defaults_from=None, deferred_accept=None, fast_open=None, finwait2timeout=None, finwait_timeout=None, idle_timeout=None, keepalive_interval=None, name=None, partition=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.ProfileTcp` Configures a custom profile_tcp for use by health checks.
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet.
        :param pulumi.Input[float] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[float] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[float] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[float] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] name: Name of the profile_tcp
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_tcp.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['close_wait_timeout'] = close_wait_timeout
            __props__['defaults_from'] = defaults_from
            __props__['deferred_accept'] = deferred_accept
            __props__['fast_open'] = fast_open
            __props__['finwait2timeout'] = finwait2timeout
            __props__['finwait_timeout'] = finwait_timeout
            __props__['idle_timeout'] = idle_timeout
            __props__['keepalive_interval'] = keepalive_interval
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['partition'] = partition
        super(ProfileTcp, __self__).__init__(
            'f5bigip:ltm/profileTcp:ProfileTcp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, close_wait_timeout=None, defaults_from=None, deferred_accept=None, fast_open=None, finwait2timeout=None, finwait_timeout=None, idle_timeout=None, keepalive_interval=None, name=None, partition=None):
        """
        Get an existing ProfileTcp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] close_wait_timeout: Specifies the number of seconds that a connection remains in a LAST-ACK state before quitting. A value of 0 represents a term of forever (or until the maxrtx of the FIN state). The default value is 5 seconds.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] deferred_accept: Specifies, when enabled, that the system defers allocation of the connection chain context until the client response is received. This option is useful for dealing with 3-way handshake DOS attacks. The default value is disabled.
        :param pulumi.Input[str] fast_open: When enabled, permits TCP Fast Open, allowing properly equipped TCP clients to send data with the SYN packet.
        :param pulumi.Input[float] finwait2timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-2 state before quitting. The default value is 300 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state).
        :param pulumi.Input[float] finwait_timeout: Specifies the number of seconds that a connection is in the FIN-WAIT-1 or closing state before quitting. The default value is 5 seconds. A value of 0 (zero) represents a term of forever (or until the maxrtx of the FIN state). You can also specify immediate or indefinite.
        :param pulumi.Input[float] idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion. The default value is 300 seconds.
        :param pulumi.Input[float] keepalive_interval: Specifies the keep alive probe interval, in seconds. The default value is 1800 seconds.
        :param pulumi.Input[str] name: Name of the profile_tcp
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_tcp.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["close_wait_timeout"] = close_wait_timeout
        __props__["defaults_from"] = defaults_from
        __props__["deferred_accept"] = deferred_accept
        __props__["fast_open"] = fast_open
        __props__["finwait2timeout"] = finwait2timeout
        __props__["finwait_timeout"] = finwait_timeout
        __props__["idle_timeout"] = idle_timeout
        __props__["keepalive_interval"] = keepalive_interval
        __props__["name"] = name
        __props__["partition"] = partition
        return ProfileTcp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class DeviceGroup(pulumi.CustomResource):
    auto_sync: pulumi.Output[str]
    """
    Specifies if the device-group will automatically sync configuration data to its members
    """
    description: pulumi.Output[str]
    devices: pulumi.Output[list]
    """
    Name of the device to be included in device group, this need to be configured before using devicegroup resource
    
      * `name` (`str`) - Is the name of the device Group
      * `setSyncLeader` (`bool`)
    """
    full_load_on_sync: pulumi.Output[str]
    incremental_config: pulumi.Output[float]
    name: pulumi.Output[str]
    """
    Is the name of the device Group
    """
    network_failover: pulumi.Output[str]
    partition: pulumi.Output[str]
    save_on_auto_sync: pulumi.Output[str]
    type: pulumi.Output[str]
    """
    Specifies if the device-group will be used for failover or resource syncing
    """
    def __init__(__self__, resource_name, opts=None, auto_sync=None, description=None, devices=None, full_load_on_sync=None, incremental_config=None, name=None, network_failover=None, partition=None, save_on_auto_sync=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        `cm.DeviceGroup` A device group is a collection of BIG-IP devices that are configured to securely synchronize their BIG-IP configuration data, and fail over when needed.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[list] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[str] name: Is the name of the device Group
        :param pulumi.Input[str] type: Specifies if the device-group will be used for failover or resource syncing
        
        The **devices** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - Is the name of the device Group
          * `setSyncLeader` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/cm_devicegroup.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auto_sync'] = auto_sync
            __props__['description'] = description
            __props__['devices'] = devices
            __props__['full_load_on_sync'] = full_load_on_sync
            __props__['incremental_config'] = incremental_config
            __props__['name'] = name
            __props__['network_failover'] = network_failover
            __props__['partition'] = partition
            __props__['save_on_auto_sync'] = save_on_auto_sync
            __props__['type'] = type
        super(DeviceGroup, __self__).__init__(
            'f5bigip:cm/deviceGroup:DeviceGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auto_sync=None, description=None, devices=None, full_load_on_sync=None, incremental_config=None, name=None, network_failover=None, partition=None, save_on_auto_sync=None, type=None):
        """
        Get an existing DeviceGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auto_sync: Specifies if the device-group will automatically sync configuration data to its members
        :param pulumi.Input[list] devices: Name of the device to be included in device group, this need to be configured before using devicegroup resource
        :param pulumi.Input[str] name: Is the name of the device Group
        :param pulumi.Input[str] type: Specifies if the device-group will be used for failover or resource syncing
        
        The **devices** object supports the following:
        
          * `name` (`pulumi.Input[str]`) - Is the name of the device Group
          * `setSyncLeader` (`pulumi.Input[bool]`)

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/cm_devicegroup.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["auto_sync"] = auto_sync
        __props__["description"] = description
        __props__["devices"] = devices
        __props__["full_load_on_sync"] = full_load_on_sync
        __props__["incremental_config"] = incremental_config
        __props__["name"] = name
        __props__["network_failover"] = network_failover
        __props__["partition"] = partition
        __props__["save_on_auto_sync"] = save_on_auto_sync
        __props__["type"] = type
        return DeviceGroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Pool(pulumi.CustomResource):
    allow_nat: pulumi.Output[str]
    allow_snat: pulumi.Output[str]
    description: pulumi.Output[str]
    """
    Userdefined value to describe the pool 
    """
    load_balancing_mode: pulumi.Output[str]
    monitors: pulumi.Output[list]
    """
    List of monitor names to associate with the pool
    """
    name: pulumi.Output[str]
    """
    Name of the pool
    """
    reselect_tries: pulumi.Output[float]
    service_down_action: pulumi.Output[str]
    slow_ramp_time: pulumi.Output[float]
    def __init__(__self__, resource_name, opts=None, allow_nat=None, allow_snat=None, description=None, load_balancing_mode=None, monitors=None, name=None, reselect_tries=None, service_down_action=None, slow_ramp_time=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.Pool` Manages a pool configuration.
        
        Resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Userdefined value to describe the pool 
        :param pulumi.Input[list] monitors: List of monitor names to associate with the pool
        :param pulumi.Input[str] name: Name of the pool

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_pool.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['allow_nat'] = allow_nat
            __props__['allow_snat'] = allow_snat
            __props__['description'] = description
            __props__['load_balancing_mode'] = load_balancing_mode
            __props__['monitors'] = monitors
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['reselect_tries'] = reselect_tries
            __props__['service_down_action'] = service_down_action
            __props__['slow_ramp_time'] = slow_ramp_time
        super(Pool, __self__).__init__(
            'f5bigip:ltm/pool:Pool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, allow_nat=None, allow_snat=None, description=None, load_balancing_mode=None, monitors=None, name=None, reselect_tries=None, service_down_action=None, slow_ramp_time=None):
        """
        Get an existing Pool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Userdefined value to describe the pool 
        :param pulumi.Input[list] monitors: List of monitor names to associate with the pool
        :param pulumi.Input[str] name: Name of the pool

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_pool.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["allow_nat"] = allow_nat
        __props__["allow_snat"] = allow_snat
        __props__["description"] = description
        __props__["load_balancing_mode"] = load_balancing_mode
        __props__["monitors"] = monitors
        __props__["name"] = name
        __props__["reselect_tries"] = reselect_tries
        __props__["service_down_action"] = service_down_action
        __props__["slow_ramp_time"] = slow_ramp_time
        return Pool(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class DataGroup(pulumi.CustomResource):
    name: pulumi.Output[str]
    """
    , sets the value of the record's `name` attribute, must be of type defined in `type` attribute
    """
    records: pulumi.Output[list]
    """
    a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
    
      * `data` (`str`) - , sets the value of the record's `data` attribute, specifying a value here will create a record in the form of `name := data`
      * `name` (`str`) - , sets the value of the record's `name` attribute, must be of type defined in `type` attribute
    """
    type: pulumi.Output[str]
    """
    datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
    """
    def __init__(__self__, resource_name, opts=None, name=None, records=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.DataGroup` Manages internal (in-line) datagroup configuration
        
        Resource should be named with their "full path". The full path is the combination of the partition + name of the resource, for example /Common/my-datagroup.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: , sets the value of the record's `name` attribute, must be of type defined in `type` attribute
        :param pulumi.Input[list] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        
        The **records** object supports the following:
        
          * `data` (`pulumi.Input[str]`) - , sets the value of the record's `data` attribute, specifying a value here will create a record in the form of `name := data`
          * `name` (`pulumi.Input[str]`) - , sets the value of the record's `name` attribute, must be of type defined in `type` attribute

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_datagroup.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['records'] = records
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
        super(DataGroup, __self__).__init__(
            'f5bigip:ltm/dataGroup:DataGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, name=None, records=None, type=None):
        """
        Get an existing DataGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: , sets the value of the record's `name` attribute, must be of type defined in `type` attribute
        :param pulumi.Input[list] records: a set of `name` and `data` attributes, name must be of type specified by the `type` attributed (`string`, `ip` and `integer`), data is optional and can take any value, multiple `record` sets can be specified as needed.
        :param pulumi.Input[str] type: datagroup type (applies to the `name` field of the record), supports: `string`, `ip` or `integer`
        
        The **records** object supports the following:
        
          * `data` (`pulumi.Input[str]`) - , sets the value of the record's `data` attribute, specifying a value here will create a record in the form of `name := data`
          * `name` (`pulumi.Input[str]`) - , sets the value of the record's `name` attribute, must be of type defined in `type` attribute

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_datagroup.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["name"] = name
        __props__["records"] = records
        __props__["type"] = type
        return DataGroup(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SnmpTraps(pulumi.CustomResource):
    auth_passwordencrypted: pulumi.Output[str]
    auth_protocol: pulumi.Output[str]
    community: pulumi.Output[str]
    """
    Specifies the community string used for this trap.
    """
    description: pulumi.Output[str]
    """
    The port that the trap will be sent to.
    """
    engine_id: pulumi.Output[str]
    host: pulumi.Output[str]
    """
    The host the trap will be sent to.
    """
    name: pulumi.Output[str]
    """
    Name of the snmp trap.
    """
    port: pulumi.Output[float]
    """
    User defined description.
    """
    privacy_password: pulumi.Output[str]
    privacy_password_encrypted: pulumi.Output[str]
    privacy_protocol: pulumi.Output[str]
    security_level: pulumi.Output[str]
    security_name: pulumi.Output[str]
    version: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, auth_passwordencrypted=None, auth_protocol=None, community=None, description=None, engine_id=None, host=None, name=None, port=None, privacy_password=None, privacy_password_encrypted=None, privacy_protocol=None, security_level=None, security_name=None, version=None, __props__=None, __name__=None, __opts__=None):
        """
        `sys.SnmpTraps` provides details bout how to enable snmp_traps resource on BIG-IP
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] community: Specifies the community string used for this trap.
        :param pulumi.Input[str] description: The port that the trap will be sent to.
        :param pulumi.Input[str] host: The host the trap will be sent to.
        :param pulumi.Input[str] name: Name of the snmp trap.
        :param pulumi.Input[float] port: User defined description.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_snmp_traps.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['auth_passwordencrypted'] = auth_passwordencrypted
            __props__['auth_protocol'] = auth_protocol
            __props__['community'] = community
            __props__['description'] = description
            __props__['engine_id'] = engine_id
            __props__['host'] = host
            __props__['name'] = name
            __props__['port'] = port
            __props__['privacy_password'] = privacy_password
            __props__['privacy_password_encrypted'] = privacy_password_encrypted
            __props__['privacy_protocol'] = privacy_protocol
            __props__['security_level'] = security_level
            __props__['security_name'] = security_name
            __props__['version'] = version
        super(SnmpTraps, __self__).__init__(
            'f5bigip:sys/snmpTraps:SnmpTraps',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auth_passwordencrypted=None, auth_protocol=None, community=None, description=None, engine_id=None, host=None, name=None, port=None, privacy_password=None, privacy_password_encrypted=None, privacy_protocol=None, security_level=None, security_name=None, version=None):
        """
        Get an existing SnmpTraps resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] community: Specifies the community string used for this trap.
        :param pulumi.Input[str] description: The port that the trap will be sent to.
        :param pulumi.Input[str] host: The host the trap will be sent to.
        :param pulumi.Input[str] name: Name of the snmp trap.
        :param pulumi.Input[float] port: User defined description.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/sys_snmp_traps.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["auth_passwordencrypted"] = auth_passwordencrypted
        __props__["auth_protocol"] = auth_protocol
        __props__["community"] = community
        __props__["description"] = description
        __props__["engine_id"] = engine_id
        __props__["host"] = host
        __props__["name"] = name
        __props__["port"] = port
        __props__["privacy_password"] = privacy_password
        __props__["privacy_password_encrypted"] = privacy_password_encrypted
        __props__["privacy_protocol"] = privacy_protocol
        __props__["security_level"] = security_level
        __props__["security_name"] = security_name
        __props__["version"] = version
        return SnmpTraps(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('f5bigip')

address = __config__.get('address')
"""
Domain name/IP of the BigIP
"""

login_ref = __config__.get('loginRef')
"""
Login reference for token authentication (see BIG-IP REST docs for details)
"""

password = __config__.get('password')
"""
The user's password
"""

port = __config__.get('port')
"""
Management Port to connect to Bigip
"""

token_auth = __config__.get('tokenAuth')
"""
Enable to use an external authentication source (LDAP, TACACS, etc)
"""

username = __config__.get('username')
"""
Username with API access to the BigIP
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SelfIp(pulumi.CustomResource):
    ip: pulumi.Output[str]
    """
    The Self IP's address and netmask.
    """
    name: pulumi.Output[str]
    """
    Name of the selfip
    """
    traffic_group: pulumi.Output[str]
    """
    Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
    """
    vlan: pulumi.Output[str]
    """
    Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.
    """
    def __init__(__self__, resource_name, opts=None, ip=None, name=None, traffic_group=None, vlan=None, __props__=None, __name__=None, __opts__=None):
        """
        `net.SelfIp` Manages a selfip configuration
        
        Resource should be named with their "full path". The full path is the combination of the partition + name of the resource, for example /Common/my-selfip.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ip: The Self IP's address and netmask.
        :param pulumi.Input[str] name: Name of the selfip
        :param pulumi.Input[str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        :param pulumi.Input[str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/net_selfip.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if ip is None:
                raise TypeError("Missing required property 'ip'")
            __props__['ip'] = ip
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['traffic_group'] = traffic_group
            if vlan is None:
                raise TypeError("Missing required property 'vlan'")
            __props__['vlan'] = vlan
        super(SelfIp, __self__).__init__(
            'f5bigip:net/selfIp:SelfIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, ip=None, name=None, traffic_group=None, vlan=None):
        """
        Get an existing SelfIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ip: The Self IP's address and netmask.
        :param pulumi.Input[str] name: Name of the selfip
        :param pulumi.Input[str] traffic_group: Specifies the traffic group, defaults to `traffic-group-local-only` if not specified.
        :param pulumi.Input[str] vlan: Specifies the VLAN for which you are setting a self IP address. This setting must be provided when a self IP is created.

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/net_selfip.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["ip"] = ip
        __props__["name"] = name
        __props__["traffic_group"] = traffic_group
        __props__["vlan"] = vlan
        return SelfIp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Snat(pulumi.CustomResource):
    autolasthop: pulumi.Output[str]
    full_path: pulumi.Output[str]
    mirror: pulumi.Output[str]
    """
    Enables or disables mirroring of SNAT connections.
    """
    name: pulumi.Output[str]
    """
    Name of the snat
    """
    origins: pulumi.Output[list]
    """
    IP or hostname of the snat
    
      * `app_service` (`str`)
      * `name` (`str`) - Name of the snat
    """
    partition: pulumi.Output[str]
    """
    Displays the administrative partition within which this profile resides
    """
    snatpool: pulumi.Output[str]
    """
    Specifies the name of a SNAT pool. You can only use this option when automap and translation are not used.
    """
    sourceport: pulumi.Output[str]
    """
    Specifies whether the system preserves the source port of the connection. The default is preserve. Use of the preserve-strict setting should be restricted to UDP only under very special circumstances such as nPath or transparent (that is, no translation of any other L3/L4 field), where there is a 1:1 relationship between virtual IP addresses and node addresses, or when clustered multi-processing (CMP) is disabled. The change setting is useful for obfuscating internal network addresses.
    """
    translation: pulumi.Output[str]
    """
    Specifies the name of a translated IP address. Note that translated addresses are outside the traffic management system. You can only use this option when automap and snatpool are not used.
    """
    vlans: pulumi.Output[list]
    """
    Specifies the name of the VLAN to which you want to assign the SNAT. The default is vlans-enabled.
    """
    vlansdisabled: pulumi.Output[bool]
    """
    Disables the SNAT on all VLANs.
    """
    def __init__(__self__, resource_name, opts=None, autolasthop=None, full_path=None, mirror=None, name=None, origins=None, partition=None, snatpool=None, sourceport=None, translation=None, vlans=None, vlansdisabled=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.Snat` Manages a snat configuration
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mirror: Enables or disables mirroring of SNAT connections.
        :param pulumi.Input[str] name: Name of the snat
        :param pulumi.Input[list] origins: IP or hostname of the snat
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] snatpool: Specifies the name of a SNAT pool. You can only use this option when automap and translation are not used.
        :param pulumi.Input[str] sourceport: Specifies whether the system preserves the source port of the connection. The default is preserve. Use of the preserve-strict setting should be restricted to UDP only under very special circumstances such as nPath or transparent (that is, no translation of any other L3/L4 field), where there is a 1:1 relationship between virtual IP addresses and node addresses, or when clustered multi-processing (CMP) is disabled. The change setting is useful for obfuscating internal network addresses.
        :param pulumi.Input[str] translation: Specifies the name of a translated IP address. Note that translated addresses are outside the traffic management system. You can only use this option when automap and snatpool are not used.
        :param pulumi.Input[list] vlans: Specifies the name of the VLAN to which you want to assign the SNAT. The default is vlans-enabled.
        :param pulumi.Input[bool] vlansdisabled: Disables the SNAT on all VLANs.
        
        The **origins** object supports the following:
        
          * `app_service` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the snat

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_snat.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['autolasthop'] = autolasthop
            __props__['full_path'] = full_path
            __props__['mirror'] = mirror
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            if origins is None:
                raise TypeError("Missing required property 'origins'")
            __props__['origins'] = origins
            __props__['partition'] = partition
            __props__['snatpool'] = snatpool
            __props__['sourceport'] = sourceport
            __props__['translation'] = translation
            __props__['vlans'] = vlans
            __props__['vlansdisabled'] = vlansdisabled
        super(Snat, __self__).__init__(
            'f5bigip:ltm/snat:Snat',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, autolasthop=None, full_path=None, mirror=None, name=None, origins=None, partition=None, snatpool=None, sourceport=None, translation=None, vlans=None, vlansdisabled=None):
        """
        Get an existing Snat resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] mirror: Enables or disables mirroring of SNAT connections.
        :param pulumi.Input[str] name: Name of the snat
        :param pulumi.Input[list] origins: IP or hostname of the snat
        :param pulumi.Input[str] partition: Displays the administrative partition within which this profile resides
        :param pulumi.Input[str] snatpool: Specifies the name of a SNAT pool. You can only use this option when automap and translation are not used.
        :param pulumi.Input[str] sourceport: Specifies whether the system preserves the source port of the connection. The default is preserve. Use of the preserve-strict setting should be restricted to UDP only under very special circumstances such as nPath or transparent (that is, no translation of any other L3/L4 field), where there is a 1:1 relationship between virtual IP addresses and node addresses, or when clustered multi-processing (CMP) is disabled. The change setting is useful for obfuscating internal network addresses.
        :param pulumi.Input[str] translation: Specifies the name of a translated IP address. Note that translated addresses are outside the traffic management system. You can only use this option when automap and snatpool are not used.
        :param pulumi.Input[list] vlans: Specifies the name of the VLAN to which you want to assign the SNAT. The default is vlans-enabled.
        :param pulumi.Input[bool] vlansdisabled: Disables the SNAT on all VLANs.
        
        The **origins** object supports the following:
        
          * `app_service` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`) - Name of the snat

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_snat.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["autolasthop"] = autolasthop
        __props__["full_path"] = full_path
        __props__["mirror"] = mirror
        __props__["name"] = name
        __props__["origins"] = origins
        __props__["partition"] = partition
        __props__["snatpool"] = snatpool
        __props__["sourceport"] = sourceport
        __props__["translation"] = translation
        __props__["vlans"] = vlans
        __props__["vlansdisabled"] = vlansdisabled
        return Snat(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ProfileHttp(pulumi.CustomResource):
    accept_xff: pulumi.Output[str]
    app_service: pulumi.Output[str]
    basic_auth_realm: pulumi.Output[str]
    """
    Specifies a quoted string for the basic authentication realm. The system sends this string to a client whenever authorization fails. The default value is none
    """
    defaults_from: pulumi.Output[str]
    """
    Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
    """
    description: pulumi.Output[str]
    encrypt_cookie_secret: pulumi.Output[str]
    encrypt_cookies: pulumi.Output[list]
    fallback_host: pulumi.Output[str]
    """
    Specifies an HTTP fallback host. HTTP redirection allows you to redirect HTTP traffic to another protocol identifier, host name, port number
    """
    fallback_status_codes: pulumi.Output[list]
    """
    Specifies one or more three-digit status codes that can be returned by an HTTP server.
    """
    head_erase: pulumi.Output[str]
    head_insert: pulumi.Output[str]
    """
    Specifies a quoted header string that you want to insert into an HTTP request
    """
    insert_xforwarded_for: pulumi.Output[str]
    """
    When using connection pooling, which allows clients to make use of other client requests' server-side connections, you can insert the X-Forwarded-For header and specify a client IP address
    """
    lws_separator: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    Name of the profile_http
    """
    oneconnect_transformations: pulumi.Output[str]
    """
    Enables the system to perform HTTP header transformations for the purpose of  keeping server-side connections open. This feature requires configuration of a OneConnect profile
    """
    proxy_type: pulumi.Output[str]
    redirect_rewrite: pulumi.Output[str]
    request_chunking: pulumi.Output[str]
    response_chunking: pulumi.Output[str]
    response_headers_permitteds: pulumi.Output[list]
    server_agent_name: pulumi.Output[str]
    tm_partition: pulumi.Output[str]
    via_host_name: pulumi.Output[str]
    via_request: pulumi.Output[str]
    via_response: pulumi.Output[str]
    xff_alternative_names: pulumi.Output[list]
    def __init__(__self__, resource_name, opts=None, accept_xff=None, app_service=None, basic_auth_realm=None, defaults_from=None, description=None, encrypt_cookie_secret=None, encrypt_cookies=None, fallback_host=None, fallback_status_codes=None, head_erase=None, head_insert=None, insert_xforwarded_for=None, lws_separator=None, name=None, oneconnect_transformations=None, proxy_type=None, redirect_rewrite=None, request_chunking=None, response_chunking=None, response_headers_permitteds=None, server_agent_name=None, tm_partition=None, via_host_name=None, via_request=None, via_response=None, xff_alternative_names=None, __props__=None, __name__=None, __opts__=None):
        """
        `ltm.ProfileHttp` Configures a custom profile_http for use by health checks.
        
        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] basic_auth_realm: Specifies a quoted string for the basic authentication realm. The system sends this string to a client whenever authorization fails. The default value is none
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] fallback_host: Specifies an HTTP fallback host. HTTP redirection allows you to redirect HTTP traffic to another protocol identifier, host name, port number
        :param pulumi.Input[list] fallback_status_codes: Specifies one or more three-digit status codes that can be returned by an HTTP server.
        :param pulumi.Input[str] head_insert: Specifies a quoted header string that you want to insert into an HTTP request
        :param pulumi.Input[str] insert_xforwarded_for: When using connection pooling, which allows clients to make use of other client requests' server-side connections, you can insert the X-Forwarded-For header and specify a client IP address
        :param pulumi.Input[str] name: Name of the profile_http
        :param pulumi.Input[str] oneconnect_transformations: Enables the system to perform HTTP header transformations for the purpose of  keeping server-side connections open. This feature requires configuration of a OneConnect profile

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_http.html.markdown.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['accept_xff'] = accept_xff
            __props__['app_service'] = app_service
            __props__['basic_auth_realm'] = basic_auth_realm
            if defaults_from is None:
                raise TypeError("Missing required property 'defaults_from'")
            __props__['defaults_from'] = defaults_from
            __props__['description'] = description
            __props__['encrypt_cookie_secret'] = encrypt_cookie_secret
            __props__['encrypt_cookies'] = encrypt_cookies
            __props__['fallback_host'] = fallback_host
            __props__['fallback_status_codes'] = fallback_status_codes
            __props__['head_erase'] = head_erase
            __props__['head_insert'] = head_insert
            __props__['insert_xforwarded_for'] = insert_xforwarded_for
            __props__['lws_separator'] = lws_separator
            if name is None:
                raise TypeError("Missing required property 'name'")
            __props__['name'] = name
            __props__['oneconnect_transformations'] = oneconnect_transformations
            __props__['proxy_type'] = proxy_type
            __props__['redirect_rewrite'] = redirect_rewrite
            __props__['request_chunking'] = request_chunking
            __props__['response_chunking'] = response_chunking
            __props__['response_headers_permitteds'] = response_headers_permitteds
            __props__['server_agent_name'] = server_agent_name
            __props__['tm_partition'] = tm_partition
            __props__['via_host_name'] = via_host_name
            __props__['via_request'] = via_request
            __props__['via_response'] = via_response
            __props__['xff_alternative_names'] = xff_alternative_names
        super(ProfileHttp, __self__).__init__(
            'f5bigip:ltm/profileHttp:ProfileHttp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, accept_xff=None, app_service=None, basic_auth_realm=None, defaults_from=None, description=None, encrypt_cookie_secret=None, encrypt_cookies=None, fallback_host=None, fallback_status_codes=None, head_erase=None, head_insert=None, insert_xforwarded_for=None, lws_separator=None, name=None, oneconnect_transformations=None, proxy_type=None, redirect_rewrite=None, request_chunking=None, response_chunking=None, response_headers_permitteds=None, server_agent_name=None, tm_partition=None, via_host_name=None, via_request=None, via_response=None, xff_alternative_names=None):
        """
        Get an existing ProfileHttp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.
        
        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] basic_auth_realm: Specifies a quoted string for the basic authentication realm. The system sends this string to a client whenever authorization fails. The default value is none
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] fallback_host: Specifies an HTTP fallback host. HTTP redirection allows you to redirect HTTP traffic to another protocol identifier, host name, port number
        :param pulumi.Input[list] fallback_status_codes: Specifies one or more three-digit status codes that can be returned by an HTTP server.
        :param pulumi.Input[str] head_insert: Specifies a quoted header string that you want to insert into an HTTP request
        :param pulumi.Input[str] insert_xforwarded_for: When using connection pooling, which allows clients to make use of other client requests' server-side connections, you can insert the X-Forwarded-For header and specify a client IP address
        :param pulumi.Input[str] name: Name of the profile_http
        :param pulumi.Input[str] oneconnect_transformations: Enables the system to perform HTTP header transformations for the purpose of  keeping server-side connections open. This feature requires configuration of a OneConnect profile

        > This content is derived from https://github.com/terraform-providers/terraform-provider-bigip/blob/master/website/docs/r/ltm_profile_http.html.markdown.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()
        __props__["accept_xff"] = accept_xff
        __props__["app_service"] = app_service
        __props__["basic_auth_realm"] = basic_auth_realm
        __props__["defaults_from"] = defaults_from
        __props__["description"] = description
        __props__["encrypt_cookie_secret"] = encrypt_cookie_secret
        __props__["encrypt_cookies"] = encrypt_cookies
        __props__["fallback_host"] = fallback_host
        __props__["fallback_status_codes"] = fallback_status_codes
        __props__["head_erase"] = head_erase
        __props__["head_insert"] = head_insert
        __props__["insert_xforwarded_for"] = insert_xforwarded_for
        __props__["lws_separator"] = lws_separator
        __props__["name"] = name
        __props__["oneconnect_transformations"] = oneconnect_transformations
        __props__["proxy_type"] = proxy_type
        __props__["redirect_rewrite"] = redirect_rewrite
        __props__["request_chunking"] = request_chunking
        __props__["response_chunking"] = response_chunking
        __props__["response_headers_permitteds"] = response_headers_permitteds
        __props__["server_agent_name"] = server_agent_name
        __props__["tm_partition"] = tm_partition
        __props__["via_host_name"] = via_host_name
        __props__["via_request"] = via_request
        __props__["via_response"] = via_response
        __props__["xff_alternative_names"] = xff_alternative_names
        return ProfileHttp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

